==> expfactory-3.15.tar.gz: expfactory-3.15/expfactory/forms.py <==
'''
views.py: part of expfactory package

Copyright (c) 2017-2020, Vanessa Sochat

All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
  list of conditions and the following disclaimer.

* Redistributions in binary form must reproduce the above copyright notice,
  this list of conditions and the following disclaimer in the documentation
  and/or other materials provided with the distribution.

* Neither the name of the copyright holder nor the names of its
  contributors may be used to endorse or promote products derived from
  this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

'''

from flask_wtf import FlaskForm
from wtforms import (
    StringField, 
    BooleanField
)

from wtforms.validators import DataRequired

class ParticipantForm(FlaskForm):
    '''the participant form is shown in the portal given an interactive
       (non headless) runtime. We collection an (optional) participant name,
       along with the experiments to run.
    '''
    openid = StringField('openid')
    exp_ids = StringField('exp_ids', validators=[DataRequired()])
    randomize = BooleanField('randomize', default=True)

class EntryForm(FlaskForm):
    '''the entry form is shown for a headless install. The user is required to
       enter a pre-generated token, otherwise entry is denied
    '''
    token = StringField('token', validators=[DataRequired()])

==> expfactory-3.17.tar.gz: expfactory-3.17/expfactory/forms.py <==
"""
views.py: part of expfactory package

Copyright (c) 2017-2020, Vanessa Sochat

All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
  list of conditions and the following disclaimer.

* Redistributions in binary form must reproduce the above copyright notice,
  this list of conditions and the following disclaimer in the documentation
  and/or other materials provided with the distribution.

* Neither the name of the copyright holder nor the names of its
  contributors may be used to endorse or promote products derived from
  this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

"""

from flask_wtf import FlaskForm
from wtforms import StringField, BooleanField

from wtforms.validators import DataRequired


class ParticipantForm(FlaskForm):
    """the participant form is shown in the portal given an interactive
       (non headless) runtime. We collection an (optional) participant name,
       along with the experiments to run.
    """

    openid = StringField("openid")
    exp_ids = StringField("exp_ids", validators=[DataRequired()])
    randomize = BooleanField("randomize", default=True)


class EntryForm(FlaskForm):
    """the entry form is shown for a headless install. The user is required to
       enter a pre-generated token, otherwise entry is denied
    """

    token = StringField("token", validators=[DataRequired()])
